##  Prerequisites
  * Complete the integration configuration as described in [Configuring the Integration with Jira Service Management](https://help.sap.com/docs/leanix/ea/configuring-integration-with-jira-service-management?locale=en-US&state=PRODUCTION&version=CLOUD "Connect Jira Service Management to SAP LeanIX to enable data synchronization between the systems.").
  * Identify which fact sheet types and object types you want to synchronize.
  * Determine the source of truth for each mapping.
